rMIDAS-package: rMIDAS: Multiple Imputation with Denoising Autoencoders

rMIDAS-packageR Documentation

rMIDAS: Multiple Imputation with Denoising Autoencoders

Description

rMIDAS provides an R interface to the MIDAS multiple imputation algorithm.

Details

rMIDAS is deprecated in favor of rMIDAS2, which provides the actively maintained successor interface and backend. The source repository for the successor package is https://github.com/MIDASverse/rMIDAS2. rMIDAS remains available on CRAN for existing workflows but will receive only compatibility and documentation updates.

See vignette("migrating-to-rMIDAS2", package = "rMIDAS") for guidance on moving to rMIDAS2.

Author(s)

Maintainer: Thomas Robinson ts.robinson1994@gmail.com (ORCID) [copyright holder]

Authors:

Other contributors:

  • Alex Stenlake [contributor, copyright holder]

  • Elviss Dvinskis [contributor]

See Also

Useful links:


rMIDAS documentation built on March 13, 2026, 5:07 p.m.